| bakeoff_colors | R Documentation |
Get a vector of hexadecimal color codes, or, extract a subset of colors as a
using defined color names (available using names(bakeoff_colors())).
bakeoff_colors(...)
... |
Character names of bakeoff colors. If none are specified,
returns all. If any are specified, they can be listed by names in quotes
(no need to combine with |
A named character vector of hex colors.
bakeoff_colors()
bakeoff_colors("riptide")
bakeoff_colors("baltic", "yellow")
names(bakeoff_colors())
if (require('scales')) {
scales::show_col(bakeoff_colors(), label = FALSE)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.