| episodes_raw | R Documentation |
Details about the three challenges (signature, technical, and showstopper) for each baker/episode across all 10 GBBO series.
episodes_raw
A data frame with 704 rows representing individual bakers per episode and 6 variables:
A factor denoting UK series (1-10).
A factor denoting episode number within a series.
A character string giving given or nickname.
A character string containing the bake for the signature challenge for that baker/episode.
An integer denoting the rank on the technical challenge
for that baker/episode. A rank of 1 is winner of the technical
challenge.
A character string containing the bake for the showstopper challenge for that baker/episode.
See https://en.wikipedia.org/wiki/The_Great_British_Bake_Off#Format
if (require('tibble')) {
episodes_raw
}
head(episodes_raw)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.