| scale_bakeoff | R Documentation |
Color scale constructor for bakeoff colors
scale_color_bakeoff( palette = "showstopper", discrete = TRUE, direction = 1, ... ) scale_fill_bakeoff( palette = "showstopper", discrete = TRUE, direction = 1, ... )
palette |
Character name of palette in |
discrete |
Boolean indicating whether color aesthetic is discrete or not. |
direction |
Either |
... |
Additional arguments passed to |
A function for constructing a color or a fill scale used for ggplot2 graphics.
if (require('ggplot2')) {
ggplot(ratings, aes(x = episode, y = viewers_7day, group = series, color = as.factor(series))) +
geom_line(lwd = 3) +
theme_minimal() +
scale_color_bakeoff("finale", guide = "none")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.