bakeoff_colors: Extract named bakeoff colors as hex codes
Description
Get a vector of hexadecimal color codes, or, extract a subset of colors as a
using defined color names (available using names(bakeoff_colors())).
Usage
bakeoff_colors(...)
Value
A named character vector of hex colors.
Arguments
...
Character names of bakeoff colors. If none are specified,
returns all. If any are specified, they can be listed by names in quotes
(no need to combine with c()).