powered by
Results of a knowledge test from Junior Bake Off (Series 2, Episode 14).
spice_test_wide
A data frame with 4 rows representing baker results from the spice-based knowledge test and 7 variables:
A character string with a given name or nickname.
The different guesses (in order) for what the mystery spice was.
An integer whether the guess was correct (1) or wrong (0).
1
0
if (require('tibble')) { spice_test_wide } head(spice_test_wide)
Run the code above in your browser using DataLab